@@ -25,6 +25,10 @@ from kfp.compiler._op_to_template import _process_obj, _inputs_to_json, _outputs
 from kfp.dsl._container_op import BaseOp
 
 from kfp_tekton.compiler import __tekton_api_version__ as tekton_api_version
+from .. import __version__
+
+
+RESOURCE_OP_IMAGE = ":".join(["aipipeline/kubectl-wrapper", __version__])
 
 
 def _get_base_step(name: str):
@@ -102,7 +106,7 @@ def _get_resourceOp_template(op: BaseOp,
                 {
                     # This image is hosted by the kfp-tekton maintainers
                     # Source code: https://github.com/kubeflow/kfp-tekton/tree/master/tekton-catalog/kubectl-wrapper
-                    "default": "index.docker.io/aipipeline/kubeclient:v0.0.2",
+                    "default": RESOURCE_OP_IMAGE,
                     "description": "Kubectl wrapper image",
                     "name": "image",
                     "type": "string"
@@ -246,6 +250,8 @@ def _process_parameters(processed_op: BaseOp,
                             need_copy_step = False
                         args.append(a)
                     s['args'] = args
+                if path == '/tekton/results/' + sanitize_k8s_name(name):
+                    need_copy_step = False
             # If file output path cannot be found/replaced, use emptyDir to copy it to the tekton/results path
             if need_copy_step:
                 copy_results_step['script'] = copy_results_step['script'] + 'cp ' + path + ' $(results.%s.path);' \
@@ -254,7 +260,7 @@ def _process_parameters(processed_op: BaseOp,
                 if mount_path not in mounted_param_paths:
                     _add_mount_path(name, path, mount_path, volume_mount_step_template, volume_template, mounted_param_paths)
             # Record what artifacts are moved to result parameters.
-            parameter_name = sanitize_k8s_name(processed_op.name + '-' + name, allow_capital_underscore=True)
+            parameter_name = sanitize_k8s_name(processed_op.name + '-' + name, allow_capital_underscore=True, max_length=float('Inf'))
             replaced_param_list.append(parameter_name)
             artifact_to_result_mapping[parameter_name] = name
         return copy_results_step
@@ -287,19 +293,21 @@ def _process_output_artifacts(outputs_dict: Dict[Text, Any],
     if outputs_dict.get('artifacts'):
         mounted_artifact_paths = []
         for artifact in outputs_dict['artifacts']:
-            artifact_name = artifact_to_result_mapping.get(artifact['name'], artifact['name'])
-            if artifact['name'] in replaced_param_list:
+            parameter_name = sanitize_k8s_name(artifact['name'], allow_capital_underscore=True, max_length=float('Inf'))
+            artifact_name = artifact_to_result_mapping.get(parameter_name, parameter_name)
+            if parameter_name in replaced_param_list:
                 artifact_items.append([artifact_name, "$(results.%s.path)" % sanitize_k8s_name(artifact_name)])
             else:
                 artifact_items.append([artifact_name, artifact['path']])
-                if artifact['path'].rsplit("/", 1)[0] not in mounted_artifact_paths:
-                    if artifact['path'].rsplit("/", 1)[0] == "":
+                mount_path = artifact['path'].rsplit("/", 1)[0]
+                if mount_path not in mounted_artifact_paths:
+                    if mount_path == "":
                         raise ValueError('Undefined volume path or "/" path artifacts are not allowed.')
                     volume_mount_step_template.append({
-                        'name': sanitize_k8s_name(artifact['name']), 'mountPath': artifact['path'].rsplit("/", 1)[0]
+                        'name': parameter_name, 'mountPath': mount_path
                     })
-                    volume_template.append({'name': sanitize_k8s_name(artifact['name']), 'emptyDir': {}})
-                    mounted_artifact_paths.append(artifact['path'].rsplit("/", 1)[0])
+                    volume_template.append({'name': parameter_name, 'emptyDir': {}})
+                    mounted_artifact_paths.append(mount_path)
 
 
 def _process_base_ops(op: BaseOp):
